/*
 * packetmodeller/netdevice.h
 * $Rev: 846 $
 *
 * Copyright (C) 2008-2009 Reto Gantenbein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#ifndef __NETDEV_H
#define __NETDEV_H

/**
 * @file netdevice.h
 * @brief Interface for network device handling
 */

/* INCLUDES *******************************************************************/

#include <netinet/in.h>         // struct in_addr, struct in6_addr
#include <netdb.h>              // struct addrinfo


/* CUSTOM NETWORK TYPES *******************************************************/

/** Storage for IPv4 or IPv6 address structures */
typedef union {
    struct in_addr     v4addr;  /**< IPv4 IP address structure */
    struct in6_addr    v6addr;  /**< IPv6 IP address structure */
} addr_storage;


/* NETWORK DEVICE RELATED PUBLIC FUNCTIONS ************************************/

int
init_udp_socket();

int
get_mac_by_dev(unsigned char *, const char *);

int
get_ip_by_dev(addr_storage *, const char *);

int
get_mtu_by_dev(const char *);

int
bind_net_socket(const struct addrinfo *addr);

int
open_tap_socket(const char *);

#endif
